.. Django GitHub webhooks documentation master file, created by
   sphinx-quickstart on Sat Jun 13 18:32:29 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Django GitHub webhooks's documentation!
==================================================

.. image:: https://github.com/OpenWiden/django-github-webhooks/workflows/Python%20package/badge.svg?branch=master
    :target: https://github.com/OpenWiden/django-github-webhooks/workflows/Python%20package/badge.svg?branch=master
    :alt: Build status

.. image:: https://codecov.io/gh/OpenWiden/django-github-webhooks/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/OpenWiden/django-github-webhooks
    :alt: Code coverage

.. image:: https://readthedocs.org/projects/django-github-webhooks/badge/?version=latest
    :target: https://django-github-webhooks.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://pyup.io/repos/github/OpenWiden/django-github-webhooks/shield.svg
     :target: https://pyup.io/repos/github/OpenWiden/django-github-webhooks/
     :alt: Updates

Table Of Contents
=================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   configuration
   user_guide
   advanced_user_guide
   history
